summaryrefslogtreecommitdiffstats
path: root/native/src/window
diff options
context:
space:
mode:
authorLibravatar Héctor Ramón Jiménez <hector0193@gmail.com>2020-01-16 07:18:17 +0100
committerLibravatar Héctor Ramón Jiménez <hector0193@gmail.com>2020-01-16 07:18:17 +0100
commitb3106738eba09a7dec98f28738ab29996654491f (patch)
tree15af856db58af15c281d966a8d24e9a11426dc89 /native/src/window
parentf73bacb454615566abdbf45065e3fd11a3276d93 (diff)
downloadiced-b3106738eba09a7dec98f28738ab29996654491f.tar.gz
iced-b3106738eba09a7dec98f28738ab29996654491f.tar.bz2
iced-b3106738eba09a7dec98f28738ab29996654491f.zip
Produce new window file events in `iced_winit`
Diffstat (limited to 'native/src/window')
-rw-r--r--native/src/window/event.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/native/src/window/event.rs b/native/src/window/event.rs
index c913385b..b177141a 100644
--- a/native/src/window/event.rs
+++ b/native/src/window/event.rs
@@ -26,7 +26,7 @@ pub enum Event {
/// A file was hovered, but has exited the window.
///
- /// There will be a single `FilesLeft` event triggered even if multiple
- /// files were hovered.
- FilesLeft,
+ /// There will be a single `FilesHoveredLeft` event triggered even if
+ /// multiple files were hovered.
+ FilesHoveredLeft,
}